#

##

###

###

##

##

    	ships

    	on
    		sesssion 1
    			docker compose up -d; docker exec -it ships.1 bash
    			. /habitat/_controls/build_1.sh

    		sesssion 2
    			docker exec -it ships.1 bash
    			. /habitat/_controls/build_2.sh

    	status
    		cd /habitat/fields/gardens/ships/_status
    		python3 status.proc.py

    	publishing

    		(cp /ships/fields/gardens/ships/module.MD readme.md)

    		#
    		#	statuses
    		#
    		python3 /habitat/fields/gardens/ships/_status/status.proc.py

    		#
    		#	git push
    		#
    		#		if Circle CI is successful, then publish
    		#

    		#
    		#	increase version
    		#

    		git add --all
    		git commit -m "save"
    		git tag 1.6.0
    		git push --tags

    		#
    		#	poetry auth
    		#
    		rm -rf dist && poetry build --verbose && poetry publish --verbose;